Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorArsentiy Milchakov <milcars@mapswithme.com>2018-09-24 13:19:17 +0300
committerAleksey Belousov <beloal@users.noreply.github.com>2018-09-25 11:56:55 +0300
commita7681b5eb9c8199ba243d3efa3aacc0077320bbe (patch)
treedf2b860534ebe012ccc7c1deef705ecf62c099ee /tools
parent84e769f3c821e612846ccf329dfc314df180e13c (diff)
[strings] strings.txt is moved to data/strings path
Diffstat (limited to 'tools')
-rwxr-xr-xtools/python/clean_strings_txt.py2
-rwxr-xr-xtools/python/find_untranslated_strings.py2
-rwxr-xr-xtools/python_tests/permissions_test.py1
-rwxr-xr-xtools/ruby/category_consistency/check_consistency.rb2
-rwxr-xr-xtools/unix/generate_localizations.sh5
5 files changed, 6 insertions, 6 deletions
diff --git a/tools/python/clean_strings_txt.py b/tools/python/clean_strings_txt.py
index 2d0942575c..0c3c56e093 100755
--- a/tools/python/clean_strings_txt.py
+++ b/tools/python/clean_strings_txt.py
@@ -154,7 +154,7 @@ def get_args():
parser.add_argument(
"-o", "--output",
- dest="output", default="strings.txt",
+ dest="output", default="data/strings/strings.txt",
help="""The name for the resulting file. It will be saved to the
project folder. Only relevant if the -s option is set."""
)
diff --git a/tools/python/find_untranslated_strings.py b/tools/python/find_untranslated_strings.py
index 99345a2783..402d09b315 100755
--- a/tools/python/find_untranslated_strings.py
+++ b/tools/python/find_untranslated_strings.py
@@ -23,7 +23,7 @@ class StringsTxt:
def __init__(self, strings_path=None):
if not strings_path:
- self.strings_path = join(dirname(argv[0]), "..", "..", "strings.txt")
+ self.strings_path = join(dirname(argv[0]), "..", "..", "data","strings", "strings.txt")
else:
self.strings_path = strings_path
diff --git a/tools/python_tests/permissions_test.py b/tools/python_tests/permissions_test.py
index 7ea69b210d..a825cda315 100755
--- a/tools/python_tests/permissions_test.py
+++ b/tools/python_tests/permissions_test.py
@@ -83,7 +83,6 @@ class TestPermissions(unittest.TestCase):
def contains_correct_files(self, my_path):
dir_contents = listdir(my_path)
return (
- "strings.txt" in dir_contents or
"android" in dir_contents or
"drape_frontend" in dir_contents
)
diff --git a/tools/ruby/category_consistency/check_consistency.rb b/tools/ruby/category_consistency/check_consistency.rb
index 6558cdd61e..f94dd030e5 100755
--- a/tools/ruby/category_consistency/check_consistency.rb
+++ b/tools/ruby/category_consistency/check_consistency.rb
@@ -6,7 +6,7 @@ ROOT = File.expand_path(File.dirname(__FILE__))
OMIM_ROOT = File.join(ROOT, '..', '..', '..')
CPP_CATEGORIES_FILENAME = File.join(OMIM_ROOT, 'search', 'displayed_categories.cpp')
CATEGORIES_FILENAME = File.join(OMIM_ROOT, 'data', 'categories.txt')
-STRINGS_FILENAME = File.join(OMIM_ROOT, 'strings.txt')
+STRINGS_FILENAME = File.join(OMIM_ROOT, 'data', 'strings', 'strings.txt')
CATEGORIES_MATCHER = /m_keys = \{(.*)\};/m
def load_categories_from_cpp(filename)
diff --git a/tools/unix/generate_localizations.sh b/tools/unix/generate_localizations.sh
index 60b5b23645..97f537dc6b 100755
--- a/tools/unix/generate_localizations.sh
+++ b/tools/unix/generate_localizations.sh
@@ -3,9 +3,10 @@ set -e -u -x
OMIM_PATH="$(dirname "$0")/../.."
TWINE="$OMIM_PATH/tools/twine/twine"
+STRINGS_PATH="$OMIM_PATH/data/strings"
MERGED_FILE="$(mktemp)"
-cat "$OMIM_PATH/strings.txt" "$OMIM_PATH/partners_strings.txt" "$OMIM_PATH/data/types_strings.txt" > "$MERGED_FILE"
+cat "$STRINGS_PATH/strings.txt" "$STRINGS_PATH/partners_strings.txt" "$STRINGS_PATH/types_strings.txt" > "$MERGED_FILE"
# TODO: Add "--untagged --tags android" when tags are properly set.
# TODO: Add validate-strings-file call to check for duplicates (and avoid Android build errors) when tags are properly set.
@@ -16,6 +17,6 @@ $TWINE generate-all-localization-files --format apple --file-name InfoPlist.stri
$TWINE generate-all-localization-files --format jquery "$OMIM_PATH/data/cuisines.txt" "$OMIM_PATH/data/cuisine-strings/"
$TWINE generate-all-localization-files --format jquery "$OMIM_PATH/data/countries_names.txt" "$OMIM_PATH/data/countries-strings/"
$TWINE generate-all-localization-files --format jquery "$OMIM_PATH/data/sound.txt" "$OMIM_PATH/data/sound-strings/"
#$TWINE generate-all-localization-files --include translated --format tizen "$OMIM_PATH/strings.txt" "$OMIM_PATH/tizen/MapsWithMe/res/" --tags tizen
rm $MERGED_FILE
@@ -16,6 +17,6 @@ $TWINE generate-all-localization-files --format apple --file-name InfoPlist.stri
$TWINE generate-all-localization-files --format jquery "$OMIM_PATH/data/countries_names.txt" "$OMIM_PATH/data/countries-strings/"
$TWINE generate-all-localization-files --format jquery "$OMIM_PATH/data/sound.txt" "$OMIM_PATH/data/sound-strings/"
-#$TWINE generate-all-localization-files --include translated --format tizen "$OMIM_PATH/strings.txt" "$OMIM_PATH/tizen/MapsWithMe/res/" --tags tizen
+#$TWINE generate-all-localization-files --include translated --format tizen "$STRINGS_PATH/strings.txt" "$OMIM_PATH/tizen/MapsWithMe/res/" --tags tizen
rm $MERGED_FILE